#!/bin/bash


usage() {
    echo "Usage: $0 [--productname <product>] [--version <version>] /path/to/tree/"
    exit 1
}

SIZE=1440

while [ $# -gt 1 ]; do
    case $1 in
	--productname)
	    PROD="$2"
	    shift ; shift
	    ;;
	--version)
	    VERSION=$2
	    shift; shift
	    ;;
	--size)
	    SIZE=$2
	    shift ; shift
	    ;;
	*)
	    usage
	    ;;
    esac
done

if [ -z "$PROD" ]; then
    usage
fi

if [ -z "$VERSION" ]; then
    usage
fi

DIR=$1
if [ ! -d $DIR/RedHat/base ]; then
    usage
fi

p=`cd $DIR; /bin/pwd`
BUILDPRODDIR=$p/buildprod.tree.$$
rm -rf $BUILDPRODDIR
mkdir -p $BUILDPRODDIR

pushd $BUILDPRODDIR
rpm2cpio $p/RedHat/RPMS/anaconda-product-[0-9]* |cpio --quiet -iumd './usr*'
popd

image=/tmp/product.img.$$
mntpt=/tmp/product.mnt.$$

mkdir $mntpt
dd if=/dev/zero of=$image bs=1k count=$SIZE
/sbin/mke2fs -F -q $image

# FIXME: this is something of a hack
if [ -f $DIR/RedHat/base/stage2.img ]; then
    mount -o loop $DIR/RedHat/base/stage2.img $mntpt
    UUID=`head -n 1 $mntpt/.buildstamp`
    umount $mntpt
else
    UUID=$(date +%Y%m%d%H%M)
fi

mount -t ext2 $image $mntpt -o loop

# make the stamp
rm -f $mntpt/.buildstamp
echo $UUID >> $mntpt/.buildstamp
echo $PROD >> $mntpt/.buildstamp
echo $VERSION >> $mntpt/.buildstamp
echo "RedHat" >> $mntpt/.buildstamp

# now set up installclasses
if [ -d $BUILDPRODDIR/usr/lib/anaconda/installclasses ]; then
    mkdir $mntpt/installclasses
    cp -a $BUILDPRODDIR/usr/lib/anaconda/installclasses/* $mntpt/installclasses
fi

# and images
if [ -d $BUILDPRODDIR/usr/share/anaconda-product/pixmaps ]; then
    mkdir $mntpt/pixmaps
    cp -a $BUILDPRODDIR/usr/share/anaconda-product/pixmaps/* $mntpt/pixmaps
fi

umount $mntpt
cp $image $DIR/RedHat/base/product.img

rm -rf $BUILDPRODDIR
exit 0
